@@ -1,12 +1,13 @@
-from marshmallow import Schema, fields, post_load
+from marshmallow import fields
 
 from flag_engine.organisations.schemas import OrganisationSchema
 from flag_engine.projects.models import ProjectModel
 from flag_engine.segments.schemas import SegmentSchema
-from flag_engine.utils.fields import ListOrDjangoRelatedManagerField
+from flag_engine.utils.marshmallow.fields import ListOrDjangoRelatedManagerField
+from flag_engine.utils.marshmallow.schemas import LoadToModelSchema
 
 
-class ProjectSchema(Schema):
+class ProjectSchema(LoadToModelSchema):
     id = fields.Int()
     name = fields.Str()
     segments = ListOrDjangoRelatedManagerField(
@@ -15,6 +16,5 @@ class ProjectSchema(Schema):
     organisation = fields.Nested(OrganisationSchema)
     hide_disabled_flags = fields.Bool()
 
-    @post_load()
-    def make_project(self, data, **kwargs) -> ProjectModel:
-        return ProjectModel(**data)
+    class Meta:
+        model_class = ProjectModel
